@@ -131,6 +131,7 @@ class GbpOptionParser(OptionParser):
                 'full': 'False',
                 'git-author': 'False',
                 'git-log': '--no-merges',
+                'git-ref': 'upstream/latest',
                 'hooks': 'True',
                 'id-length': '0',
                 'ignore-branch': 'False',
@@ -162,6 +163,7 @@ class GbpOptionParser(OptionParser):
                 'posttag': '',
                 'pq-from': 'DEBIAN',
                 'prebuild': '',
+                'preexport': '',
                 'pristine-tar': 'False',
                 'pristine-tar-commit': 'False',
                 'purge': 'True',
