@@ -22,9 +22,9 @@ import re
 from gbp.command_wrappers import CommandExecFailed
 from gbp.git import GitRepositoryError
 from gbp.deb.pristinetar import DebianPristineTar
-from gbp.format import format_str
 from gbp.paths import to_bin
 from gbp.pkg.git import PkgGitRepository
+from gbp.pkg.pkgpolicy import PkgPolicy
 
 import gbp.log
 
@@ -32,10 +32,7 @@ import gbp.log
 class DebianGitRepository(PkgGitRepository):
     """A git repository that holds the source of a Debian package"""
 
-    version_mangle_re = (r'%\(version'
-                         '%(?P<M>[^%])'
-                         '%(?P<R>([^%]|\\%))+'
-                         '\)s')
+    version_mangle_re = PkgPolicy.version_mangle_re
 
     def __init__(self, *args, **kwargs):
         super(DebianGitRepository, self).__init__(*args, **kwargs)
@@ -166,25 +163,23 @@ class DebianGitRepository(PkgGitRepository):
         'libfoo-1-8-1'
         >>> DebianGitRepository.version_to_tag("v%(version%.%_)s", "1.2.3")
         'v1_2_3'
-        >>> DebianGitRepository.version_to_tag("%(version%-%\%)s", "0-1.2.3")
+        >>> DebianGitRepository.version_to_tag(r'%(version%-%\\%)s', "0-1.2.3")
         '0%1.2.3'
         """
-        f, v = cls._mangle_version(format, version)
-        return format_str(f, dict(version=cls._sanitize_version(v),
-                                  hversion=cls._sanitize_version(v).replace('.', '-')))
+        return PkgPolicy.version_subst(format, version, cls._sanitize_version)
 
     @classmethod
     def _mangle_version(cls, format, version):
         """
         Basic version mangling to replce single characters
 
-        >>> DebianGitRepository._mangle_version("%(version%-%\%)s", "0-1.2.3")
+        >>> DebianGitRepository._mangle_version(r'%(version%-%\\%)s', "0-1.2.3")
         ('%(version)s', '0%1.2.3')
         """
         r = re.search(cls.version_mangle_re, format)
         if r:
             f = re.sub(cls.version_mangle_re, "%(version)s", format)
-            v = version.replace(r.group('M'), r.group('R').replace('\%', '%'))
+            v = version.replace(r.group('M'), r.group('R').replace(r'\%', '%'))
             return f, v
         else:
             return format, version
@@ -207,7 +202,7 @@ class DebianGitRepository(PkgGitRepository):
         """
         r = re.search(cls.version_mangle_re, format)
         if r:
-            v = tag.replace(r.group('R').replace('\%', '%'), r.group('M'))
+            v = tag.replace(r.group('R').replace(r'\%', '%'), r.group('M'))
             return v
         else:
             return tag
@@ -231,7 +226,7 @@ class DebianGitRepository(PkgGitRepository):
         >>> DebianGitRepository._sanitize_version("0.lock")
         '0.#lock'
         """
-        v = re.sub('\.(?=\.|$|lock$)', '.#', version)
+        v = re.sub(r'\.(?=\.|$|lock$)', '.#', version)
         return v.replace('~', '_').replace(':', '%')
 
     @staticmethod
@@ -262,7 +257,7 @@ class DebianGitRepository(PkgGitRepository):
         >>> DebianGitRepository.tag_to_version("foo/2.3.4", "upstream/%(version)s")
         """
         f = cls._unmangle_format(format)
-        version_re = f.replace('%(version)s', '(?P<version>[\w_%+-.#]+)')
+        version_re = f.replace('%(version)s', r'(?P<version>[\w_%+-.#]+)')
         r = re.match(version_re, tag)
         if r:
             v = cls._unsanitize_version(r.group('version'))
