@@ -32,7 +32,7 @@ class PristineTar(Command):
                                           cwd=repo.path,
                                           capture_stderr=True)
 
-    def _has_feature(self, feature):
+    def _has_in_output(self, match):
         """
         Check if pristine_tar has a certain feature enabled.
 
@@ -42,14 +42,19 @@ class PristineTar(Command):
         @rtype: C{bool}
         """
         self.call(['--help'], quiet=True)  # There's no --help so we always exit 1
-        r = re.compile('.* pristine-tar .* %s' % feature)
+        r = re.compile(match)
         for line in self.stderr.splitlines():
             if r.match(line):
                 return True
         return False
 
     def has_feature_verify(self):
-        return self._has_feature("verify")
+        """Does this pristine-tar support tarball verification"""
+        return self._has_in_output(".* pristine-tar .* verify")
+
+    def has_feature_sig(self):
+        """Does this pristine-tar support detached upstream signatures"""
+        return self._has_in_output(r'.*--signature-file')
 
     def has_commit(self, archive_regexp):
         """
@@ -78,17 +83,20 @@ class PristineTar(Command):
             return commit
         return None
 
-    def checkout(self, archive, quiet=False):
+    def checkout(self, archive, quiet=False, signaturefile=None):
         """
         Checkout an orig archive from pristine-tar branch
 
         @param archive: the name of the orig archive
         @type archive: C{str}
         """
+        args = ['checkout', archive]
         self.run_error = 'Pristine-tar couldn\'t checkout "%s": {stderr_or_reason}' % os.path.basename(archive)
-        self.__call__(['checkout', archive], quiet=quiet)
+        if signaturefile and self.has_feature_sig():
+            args += ['-s', signaturefile]
+        self.__call__(args, quiet=quiet)
 
-    def commit(self, archive, upstream, quiet=False):
+    def commit(self, archive, upstream, quiet=False, signaturefile=None):
         """
         Commit an archive I{archive} to the pristine tar branch using upstream
         branch ${upstream}.
@@ -98,9 +106,12 @@ class PristineTar(Command):
         @param upstream: the upstream branch to diff against
         @type upstream: C{str}
         """
+        args = ['commit', archive, upstream]
         self.run_error = ("Couldn't commit to '%s' with upstream '%s': {stderr_or_reason}" %
                           (self.branch, upstream))
-        self.__call__(['commit', archive, upstream], quiet=quiet)
+        if signaturefile and self.has_feature_sig():
+            args += ['-s', signaturefile]
+        self.__call__(args, quiet=quiet)
 
     def verify(self, archive, quiet=False):
         """Verify an archive's I{archive} checksum using to the pristine tar branch"""
