@@ -45,6 +45,7 @@ from gbp.scripts.common.hook import Hook
 
 from gbp.scripts.export_orig import prepare_upstream_tarballs, guess_comp_type
 from gbp.scripts.tag import perform_tagging
+from gbp.pkg.pkgpolicy import PkgPolicy
 
 
 # Functions to handle export-dir
@@ -111,7 +112,7 @@ def overlay_extract_origs(source, tarball_dir, dest_dir, options):
                                 repo=None,
                                 tarball_dir=tarball_dir)
     tarball = os.path.join(tarball_dir, source.upstream_tarball_name(comp_type))
-    gbp.log.info("Extracting %s to '%s'" % (os.path.basename(tarball), dest_dir))
+    gbp.log.info("Extracting '%s' to '%s'" % (os.path.basename(tarball), dest_dir))
 
     move_old_export(dest_dir)
     upstream = DebianUpstreamSource(tarball)
@@ -140,7 +141,7 @@ def overlay_extract_origs(source, tarball_dir, dest_dir, options):
     for c in options.components:
         tarball = os.path.join(tarball_dir, source.upstream_tarball_name(
             comp_type, component=c))
-        gbp.log.info("Unpacking '%s' to '%s'" % (os.path.basename(tarball), dest_dir))
+        gbp.log.info("Extracting '%s' to '%s/%s'" % (os.path.basename(tarball), dest_dir, c))
         unpack_component_tarball(dest_dir, c, tarball, [])
 
 
@@ -277,7 +278,7 @@ def mangle_export_wc_opts(options):
 
 def disable_hooks(options):
     """Disable all hooks (except for builder)"""
-    for hook in ['cleaner', 'postexport', 'prebuild', 'postbuild', 'posttag']:
+    for hook in ['cleaner', 'preexport', 'postexport', 'prebuild', 'postbuild', 'posttag']:
         if getattr(options, hook):
             gbp.log.info("Disabling '%s' hook" % hook)
             setattr(options, hook, '')
@@ -406,6 +407,9 @@ def build_parser(name, prefix=None):
     cmd_group.add_config_file_option(option_name="prebuild", dest="prebuild",
                                      help="hook to run before a build, "
                                           "default is '%(prebuild)s'")
+    cmd_group.add_config_file_option(option_name="preexport", dest="preexport",
+                                     help="hook to run before exporting the source tree, "
+                                          "default is '%(preexport)s'")
     cmd_group.add_config_file_option(option_name="postexport", dest="postexport",
                                      help="hook to run after exporting the source tree, "
                                           "default is '%(postexport)s'")
@@ -496,7 +500,9 @@ def main(argv):
 
         if not options.tag_only:
             output_dir = prepare_output_dir(options.export_dir)
-            tarball_dir = options.tarball_dir or output_dir
+            tarball_dir = output_dir
+            if options.tarball_dir and source.upstream_version is not None:
+                tarball_dir = PkgPolicy.version_subst(options.tarball_dir, source.upstream_version)
             tmp_dir = os.path.join(output_dir, "%s-tmp" % source.sourcepkg)
             build_env, hook_env = setup_pbuilder(options, repo, source.is_native())
             major = (source.debian_version if source.is_native()
@@ -505,6 +511,14 @@ def main(argv):
             build_dir = export_dir if options.export_dir else repo.path
             changes_file = changes_file_name(source, build_dir, options.builder, dpkg_args)
 
+            # Run preexport hook
+            if options.export_dir and options.preexport:
+                Hook('Preexport', options.preexport,
+                     extra_env=Hook.md(hook_env,
+                                       {'GBP_GIT_DIR': repo.git_dir,
+                                        'GBP_BUILD_DIR': build_dir})
+                     )()
+
             # Get/build the upstream tarball if necessary. We delay this in
             # case of a postexport hook so the hook gets a chance to modify the
             # sources and create different tarballs (#640382)
