@@ -29,6 +29,7 @@ import gbp.log
 import gbp.notifications
 from gbp.scripts.common import ExitCodes
 from gbp.pkg import Compressor, Archive
+from gbp.pkg.pkgpolicy import PkgPolicy
 
 
 def prepare_upstream_tarballs(repo, source, options, tarball_dir, output_dir):
@@ -95,7 +96,7 @@ def pristine_tar_build_origs(repo, source, output_dir, options):
     """
     Build orig tarball using pristine-tar
 
-    @returns: C{True} if tarball was build, C{False} otherwise
+    @returns: C{True} if tarball was built, C{False} otherwise
     """
     if not options.pristine_tar:
         return False
@@ -133,9 +134,9 @@ def pristine_tar_build_origs(repo, source, output_dir, options):
 
 def pristine_tar_verify_origs(repo, source, options, output_dir, orig_files):
     """
-    Verify orig tarballs using prstine tar
+    Verify orig tarballs using pristine-tar
 
-    @returns: C{True} if tarball was build, C{False} otherwise
+    @returns: C{True} if tarball was built, C{False} otherwise
     """
     if not options.pristine_tar:
         return True
@@ -235,7 +236,7 @@ def guess_comp_type(comp_type, source, repo, tarball_dir):
 
     if comp_type == 'auto':
         if repo and repo.has_pristine_tar_branch():
-            regex = 'pristine-tar .* %s_%s\.orig.tar\.' % (source.name, source.upstream_version)
+            regex = r'pristine-tar .* %s_%s\.orig.tar\.' % (source.name, source.upstream_version)
             commits = repo.grep_log(regex, repo.pristine_tar_branch, merges=False)
             if commits:
                 commit = commits[-1]
@@ -335,6 +336,10 @@ def main(argv):
         except Exception as e:
             raise GbpError("Can't determine package type: %s" % e)
 
+        if options.tarball_dir and source.upstream_version is not None:
+            options.tarball_dir = PkgPolicy.version_subst(options.tarball_dir,
+                                                          source.upstream_version)
+
         output_dir = options.tarball_dir or os.path.join(repo.path, '..')
 
         if source.is_native():
