@@ -71,7 +71,7 @@ def parse_args(argv):
 
 
 def main(argv):
-    ret = 0
+    ret = 1
     repo = None
 
     (options, args) = parse_args(argv)
@@ -100,15 +100,17 @@ def main(argv):
         repo.create_pristine_tar_commits(upstream_tag,
                                          tarball,
                                          component_tarballs)
+        ret = 0
     except (GitRepositoryError, GbpError, CommandExecFailed) as err:
         if str(err):
             gbp.log.err(err)
-        ret = 1
+    except KeyboardInterrupt:
+        gbp.log.err("Interrupted. Aborting.")
 
     if not ret:
         comp_msg = (' with additional tarballs for %s'
                     % ", ".join([os.path.basename(t[1]) for t in component_tarballs])) if component_tarballs else ''
-        gbp.log.info("Successfully committed pristine-tar data for version %s of %s%s" % (source.version,
+        gbp.log.info("Successfully committed pristine-tar data for version %s of %s%s" % (source.upstream_version,
                                                                                           tarball,
                                                                                           comp_msg))
     return ret
