@@ -60,6 +60,7 @@ def run_cmd(cmd, opts=None, capture_stdout=False, capture_stderr=False,
     ret_err = stderr.splitlines() if stderr else stderr
     return (popen.returncode, ret_out, ret_err)
 
+
 def git_cmd(cmd, opts=None, capture_stdout=False, input_data=None,
             extra_env=None):
     """Run git command"""
@@ -71,6 +72,7 @@ def git_cmd(cmd, opts=None, capture_stdout=False, input_data=None,
                        ('git ' + ' '.join(git_opts), '\n'.join(stderr)))
     return stdout
 
+
 def git_cat_file(treeish):
     """Get object content"""
     info = {}
@@ -86,9 +88,10 @@ def git_cat_file(treeish):
                 info['parents'] = [val]
         else:
             info[key] = val
-    info['message'] = output[num+1:]
+    info['message'] = output[num + 1:]
     return info
 
+
 def git_write_patch(treeish, outfile):
     """Write patch with user-defined filename"""
     cmd = ['git', 'format-patch', '-1', '--stdout', '--no-stat',
@@ -139,7 +142,7 @@ def parse_args(argv=None):
                              "new repository is created")
     # Export command
     parser = subparsers.add_parser('export-repo',
-                                    help='Serialize test package repositories')
+                                   help='Serialize test package repositories')
     parser.set_defaults(func=cmd_export_repos)
     parser.add_argument('--output-dir', '-o', default='.',
                         help="Target directory for the exported repo(s)")
@@ -163,6 +166,7 @@ def cond_copy(src, dst, overwrite=False):
     else:
         LOG.debug('Skipping %s', src)
 
+
 def do_build(tag, builddir, silent_build=False):
     """Run git-buildpackage-rpm"""
     gbp_opts = ['buildpackage-rpm', '--git-ignore-new',
@@ -173,7 +177,7 @@ def do_build(tag, builddir, silent_build=False):
                           True, silent_build)
     if ret:
         for line in out:
-            print line
+            print(line)
         raise Exception('Building %s failed! Builddata can be found '
                         'in %s' % (tag, builddir))
 
@@ -318,9 +322,9 @@ def import_commit(commit, patchdir):
     else:
         raise Exception("Merge commits (%s) not supported!" % commit['sha1'])
     # Sanity check for commit
-    assert sha1 == commit['sha1'], \
-            "SHA-1 of the created commit is wrong (%s != %s)" % \
-            (sha1, commit['sha1'])
+    assert sha1 == commit['sha1'], (
+        "SHA-1 of the created commit is wrong (%s != %s)" %
+        (sha1, commit['sha1']))
 
 
 def import_repo(datadir, repodir, force):
@@ -348,7 +352,7 @@ def import_repo(datadir, repodir, force):
         # Create child mapping of commit history
         commits = defaultdict(list)
         for sha1, info in manifest['commits'].iteritems():
-            if not 'parents' in info:
+            if 'parents' not in info:
                 commits['root'].append(sha1)
             else:
                 for parent in info['parents']:
@@ -364,9 +368,9 @@ def import_repo(datadir, repodir, force):
 
         # Re-create tags
         for sha1, tag in manifest['tags'].iteritems():
-            signature_data = "object %s\ntype %s\ntag %s\ntagger %s\n\n%s\n" % \
-                    (tag['object'], tag['type'], tag['tag'], tag['tagger'],
-                     tag['message'])
+            signature_data = "object %s\ntype %s\ntag %s\ntagger %s\n\n%s\n" % (
+                tag['object'], tag['type'], tag['tag'], tag['tagger'],
+                tag['message'])
             new_sha1 = git_cmd('mktag', None, True, signature_data)[0]
             assert new_sha1 == sha1, \
                 "SHA-1 of the re-created tag is wrong (%s != %s)" % \
@@ -440,7 +444,7 @@ def export_repo(repodir, datadir):
                                   'tagger': tag_info['tagger'],
                                   'message': '\n'.join(tag_info['message'])}
         # Serialize commits objects
-        refs = [ref for sha1, ref in refs]
+        refs = [ref for _, ref in refs]
         revisions = git_cmd('rev-list', ['--reverse'] + refs + ['--'],
                             True)
         series = defaultdict(int)
